#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: js-jquery
version: 1.12.1
id: js-jquery-1.12.1-cb4fee5dc2f301f8b48d430c321cbb84
key: jsjqu_4aj7QpZxzjoAJpTzPPSteP
license: MIT
copyright: Neil Mitchell 2014-2016
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/js-jquery#readme
synopsis: Obtain minified jQuery code
description:
    This package bundles the minified <http://jquery.com/ jQuery> code into a Haskell package,
    so it can be depended upon by Cabal packages. The first three components of
    the version number match the upstream jQuery version. The package is designed
    to meet the redistribution requirements of downstream users (e.g. Debian).
category: Javascript
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
exposed-modules:
    Language.Javascript.JQuery
hidden-modules: Paths_js_jquery
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/js-jquery-1.12.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/js-jquery-1.12.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/js-jquery-1.12.1
hs-libraries: HSjs-jquery-1.12.1-4aj7QpZxzjoAJpTzPPSteP
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
haddock-interfaces: /usr/share/doc/haskell-js-jquery/html/js-jquery.haddock
haddock-html: /usr/share/doc/haskell-js-jquery/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
